@@ -2,7 +2,7 @@ weaveR<-function(in.file,out.file,show.code=TRUE,show.text=TRUE,
                  replace.umlaute=TRUE,eval_Sexpr=FALSE){
   # german documentation of the code:
   # look for file webR.pdf, P. Wolf 050204, 060517, 070307, 070830, 110919
-  require(tcltk)
+  # require(tcltk) # 140306
   pat.use.chunk    <- paste("<","<(.*)>",">",sep="")
   pat.use.chunk.line <- paste("(.*)",pat.use.chunk,"(.*)",sep="")
   pat.chunk.header <- paste("^<","<(.*)>",">=",sep="")
@@ -741,7 +741,7 @@ weaveR<-function(in.file,out.file,show.code=TRUE,show.text=TRUE,
       if(!UTF){
       # im Tcl/Tk-Textfenster eingegeben -> iso-8859-1 
       # (see: $ man iso-8859-1 / Latin1 / unicode)
-        # \"a -> ae, ... oe, ue, Ae, Oe, Ue, 
+        # \"a -> ae, ... oe, ue, Ae, Oe, Ue, ß
         u<-uml.latin1<-unlist(strsplit(eval(parse(
              text='"\\344\\366\\374\\304\\326\\334\\337"')),""))
         inp<-gsub(paste('\\\\"',"a",sep=""),u[1],inp)
