@@ -1,7 +1,7 @@
 weaveRhtml<-function(in.file,out.file,replace.umlaute=TRUE){
   # german documentation of the code:
   # look for file webR.pdf, P. Wolf 060920 / 070309 / 070830 / 071016
-  require(tcltk)
+  # require(tcltk) # 140306
   pat.use.chunk<-paste("<","<(.*)>",">",sep="")
   pat.use.chunk.line <- paste("(.*)",pat.use.chunk,"(.*)",sep="")
   pat.chunk.header<-paste("^<","<(.*)>",">=",sep="")
